@@ -80,6 +80,7 @@ options:
         - interface l2tp-server server
         - interface list
         - interface list member
+        - interface ovpn-client
         - interface ovpn-server server
         - interface ppp-client
         - interface pppoe-client
@@ -87,6 +88,30 @@ options:
         - interface sstp-server server
         - interface vlan
         - interface vrrp
+        - interface wifi
+        - interface wifi aaa
+        - interface wifi access-list
+        - interface wifi cap
+        - interface wifi capsman
+        - interface wifi channel
+        - interface wifi configuration
+        - interface wifi datapath
+        - interface wifi interworking
+        - interface wifi provisioning
+        - interface wifi security
+        - interface wifi steering
+        - interface wifiwave2
+        - interface wifiwave2 aaa
+        - interface wifiwave2 access-list
+        - interface wifiwave2 cap
+        - interface wifiwave2 capsman
+        - interface wifiwave2 channel
+        - interface wifiwave2 configuration
+        - interface wifiwave2 datapath
+        - interface wifiwave2 interworking
+        - interface wifiwave2 provisioning
+        - interface wifiwave2 security
+        - interface wifiwave2 steering
         - interface wireguard
         - interface wireguard peers
         - interface wireless
@@ -143,6 +168,7 @@ options:
         - ip traffic-flow target
         - ip upnp
         - ip upnp interfaces
+        - ip vrf
         - ipv6 address
         - ipv6 dhcp-client
         - ipv6 dhcp-server
@@ -164,9 +190,11 @@ options:
         - ppp profile
         - queue interface
         - queue tree
+        - radius
         - radius incoming
         - routing bgp connection
         - routing bgp instance
+        - routing bgp template
         - routing filter rule
         - routing filter select-rule
         - routing id
@@ -179,6 +207,7 @@ options:
         - routing pimsm interface-template
         - routing rip
         - routing ripng
+        - routing rule
         - routing table
         - snmp
         - snmp community
@@ -1096,7 +1125,7 @@ def has_backend(versioned_path_info):
 
     if versioned_path_info.versioned is not None:
         for dummy, dummy, unversioned in versioned_path_info.versioned:
-            if get_backend(unversioned) is not None:
+            if unversioned and not isinstance(unversioned, str) and get_backend(unversioned) is not None:
                 return True
 
     return False
@@ -1133,8 +1162,12 @@ def main():
     versioned_path_info = PATHS.get(tuple(path))
     if versioned_path_info.needs_version:
         api_version = get_api_version(api)
-        if not versioned_path_info.provide_version(api_version):
-            module.fail_json(msg='Path /{path} is not supported for API version {api_version}'.format(path='/'.join(path), api_version=api_version))
+        supported, not_supported_msg = versioned_path_info.provide_version(api_version)
+        if not supported:
+            msg = 'Path /{path} is not supported for API version {api_version}'.format(path='/'.join(path), api_version=api_version)
+            if not_supported_msg:
+                msg = '{0}: {1}'.format(msg, not_supported_msg)
+            module.fail_json(msg=msg)
     path_info = versioned_path_info.get_data()
 
     backend = get_backend(path_info)
